/**
 * 配置项
 * windows 默认存储在用户 home 目录的 AppData\Local 下的 sydmark 目录
 * linux 默认存贮在用户 home 目录的 .sydmark 目录
 */

const os = require('os');
const path = require('path');
const fs = require('fs');


// 默认配置
let configMap = {
    gitAuth : "qian.huang%40sunyard.com:qian.huang",
    docAuth : ""
}

// 获取操作系统的名称
const platform = os.platform();
let baseDir = undefined
const userHomeDir = os.homedir();

// 检查操作系统类型
if (platform === 'win32') {
    console.log('操作系统是 Windows');
    baseDir = path.resolve(userHomeDir, "AppData/Local/sydmark")
} else if (platform === 'linux') {
    console.log('操作系统是 Linux');
    baseDir = path.resolve(userHomeDir, ".sydmark")
} else {
    console.log('暂不支持操作系统 ' + platform );
    process.exit(-1)
}

// 检查目录是否存在
// 如果目录不存在创建目录
if (!fs.existsSync(baseDir)) {
    // 使用递归创建目录
    fs.mkdirSync(baseDir, { recursive: true });
    console.log(`目录 ${resolvedPath} 创建成功`);
} else {
    console.log(`目录 ${resolvedPath} 已存在，无需创建`);
}

const configFile = path.resolve(baseDir, "config.json");
// 判断文件是否存在
// 如果存在读取
try {
    if ( fs.existsSync( configFile ) ) {
        let json = fs.readFileSync(configFile, "UTF-8")
        configMap = JSON.parse(json);
    } else {
        throw "unexists"
    }
} catch ( e ) {
    // 如果 不存在/读取异常 用默认值填充
    fs.writeFileSync(configFile, JSON.stringify( configMap, null, 4 ))
}

module.exports = {

    getConfig(key) {
        return configMap[key]
    },

    setConfig(key, value) {
        configMap[key] = value
        fs.writeFileSync(configFile, JSON.stringify( configMap, null, 4 ))
    }

}